@@ -206,30 +206,36 @@ class DBConnect:
         return data
 
     def find_paging(self, parameter: Parameter) -> dict:
-        parameter.verification(
-            checking=parameter.param_url,
+        # 兼容GET和POST两个请求方式
+        if parameter.method == 'GET':
+            checking = parameter.param_url
+        else:
+            checking = parameter.param_json
+        # offset表示当前页第一条在记录集中的位置，接收即可，无需处理
+        param = parameter.verification(
+            checking=checking,
             verify={
-                'page_size': str, 'current': str, 'columns': str, 'sort_order': str,
-                'filtered_value': str, 'start_date': str, 'end_date': str, 'date_type': str
+                'limit': int, 'current': int, 'select_list': list, 'orderby_list': list,
+                'filter_list': list, 'start_date': str, 'end_date': str, 'date_type': str,
+                'offset': int,
             },
-            optional={'start_date': '', 'end_date': '', 'date_type': 'update_time'})
-        param = parameter.param_url
+            optional={'start_date': '', 'end_date': '', 'date_type': 'update_time', 'offset': 0})
         try:
-            page_size = int(param['page_size'])  # 每页条数
+            limit = int(param['limit'])  # 每页条数
             current = int(param['current'])  # 当前页数
-            if current < 1 or page_size < 1:
+            if current < 1 or limit < 1:
                 raise Exception('当前页数和每页条数都从 1 开始计算')
             else:
                 current -= 1
-            columns = json.loads(param['columns'])  # 受控列
+            select_list = param['select_list']  # 受控列
             # 排序顺序（对应受控列），asc=升序，desc=降序
-            sort_order = json.loads(param['sort_order'])
+            orderby_list = param['orderby_list']
             # 筛选值（对应受控列）
-            filtered_value = json.loads(param['filtered_value'])
+            filter_list = param['filter_list']
             start_date = handle_date(date=param['start_date'])  # 可选——开始日期
             # 可选——结束日期，与开始日期组成日期区间
             end_date = handle_date(date=param['end_date'], date_type='end')
-            if len(columns) != len(sort_order) or len(columns) != len(filtered_value):
+            if len(select_list) != len(orderby_list) or len(select_list) != len(filter_list):
                 raise Exception('三个控制列表的长度不一致')
             # 查找假删除数据的数据量
             remove_count = self.mongo_collection.find(
@@ -237,25 +243,25 @@ class DBConnect:
             # 查找字典和排序列表，处理假删除数据
             find_dict = handle_db_remove({})
             sort_list = []
-            if len(columns):
-                for i in range(len(columns)):
+            if len(select_list):
+                for i in range(len(select_list)):
                     # 整理请求参数中的筛选项字典
-                    if type(filtered_value[i]) == int:
-                        find_dict[columns[i]] = filtered_value[i]
-                    elif columns[i] == 'id' or columns[i] == '_id':
-                        find_dict['_id'] = ObjectId(str(filtered_value[i]))
+                    if type(filter_list[i]) == int:
+                        find_dict[select_list[i]] = filter_list[i]
+                    elif select_list[i] == 'id' or select_list[i] == '_id':
+                        find_dict['_id'] = ObjectId(str(filter_list[i]))
                     else:
-                        if filtered_value[i].strip() != '':
-                            find_dict[columns[i]] = {
-                                '$regex': filtered_value[i]}
+                        if filter_list[i].strip() != '':
+                            find_dict[select_list[i]] = {
+                                '$regex': filter_list[i]}
                     # 整理请求参数中的筛排序列表
-                    if type(sort_order[i]) != str:
+                    if type(orderby_list[i]) != str:
                         abort(Response('计算组件分页参数异常: 排序参数不支持 int 类型', 400, {}))
-                    sort_value = sort_order[i].strip()
+                    sort_value = orderby_list[i].strip()
                     if sort_value == 'asc':
-                        sort_list.append((columns[i], pymongo.ASCENDING))
+                        sort_list.append((select_list[i], pymongo.ASCENDING))
                     elif sort_value == 'desc':
-                        sort_list.append((columns[i], pymongo.DESCENDING))
+                        sort_list.append((select_list[i], pymongo.DESCENDING))
                     elif sort_value == '':
                         pass
                     else:
@@ -267,10 +273,10 @@ class DBConnect:
             # 对排序规则处理
             if sort_list:
                 find_data = self.mongo_collection.find(find_dict).sort(sort_list).limit(
-                    page_size).skip(page_size * current)
+                    limit).skip(limit * current)
             else:
                 find_data = self.mongo_collection.find(find_dict).limit(
-                    page_size).skip(page_size * current)
+                    limit).skip(limit * current)
             # 处理返回数据
             records_filtered = find_data.count()
             # 判断数据是否为空
@@ -278,19 +284,19 @@ class DBConnect:
                 # 处理返回数据
                 query_result = handle_db_to_list(find_data)
                 return {
-                    'records_total': self.mongo_collection.estimated_document_count() - remove_count,
-                    'records_filtered': records_filtered,
-                    'query_result': query_result,
-                    'total_pages': math.ceil(records_filtered / page_size),
-                    'remove_count': remove_count,
+                    'total': self.mongo_collection.estimated_document_count() - remove_count,
+                    'filtered': records_filtered,
+                    'items': query_result,
+                    'pages': math.ceil(records_filtered / limit),
+                    'dummy_remove': remove_count,
                 }
             else:
                 return {
-                    'records_total': self.mongo_collection.estimated_document_count() - remove_count,
-                    'records_filtered': 0,
-                    'query_result': [],
-                    'total_pages': 0,
-                    'remove_count': remove_count,
+                    'total': self.mongo_collection.estimated_document_count() - remove_count,
+                    'filtered': 0,
+                    'items': [],
+                    'pages': 0,
+                    'dummy_remove': remove_count,
                 }
         except Exception as err:
             handle_abnormal(
