@@ -59,6 +59,12 @@ class Parameter():
                             checking[_k] = int(_v)
                         except ValueError as err:
                             str_data = f'参数 {_k} 应该符合 {verify[_k]} 格式'
+                    elif verify[_k] == list:
+                        # 特殊处理字符串形式 list 类型判断
+                        try:
+                            checking[_k] = json.loads(_v)
+                        except ValueError as err:
+                            str_data = f'参数 {_k} 应该符合 {verify[_k]} 格式'
                     else:
                         str_data = f'参数 {_k} 应该是 {verify[_k]} 类型'
                 if not null_value and verify[_k] == str and not optional.__contains__(_k):
